[Libreoffice-commits] core.git: sfx2/source

Libreoffice Gerrit user logerrit at kemper.freedesktop.org
Thu Nov 8 14:36:58 UTC 2018


 sfx2/source/view/viewfrm.cxx |   11 ++---------
 1 file changed, 2 insertions(+), 9 deletions(-)

New commits:
commit 9fb7c77e5cfc5add880aee18e36a851b8929137a
Author:     heiko tietze <tietze.heiko at gmail.com>
AuthorDate: Tue Nov 6 11:34:10 2018 +0100
Commit:     Heiko Tietze <tietze.heiko at gmail.com>
CommitDate: Thu Nov 8 15:35:00 2018 +0100

    tdf#120642 - GetInvoled update
    
    UNO command is used now and period set to 180 days
    
    Change-Id: Ib9950e75a5288e242c5a9a5c5a6a0c1dbb277e2b
    Reviewed-on: https://gerrit.libreoffice.org/62949
    Tested-by: Jenkins
    Reviewed-by: Heiko Tietze <tietze.heiko at gmail.com>
    Tested-by: Heiko Tietze <tietze.heiko at gmail.com>

diff --git a/sfx2/source/view/viewfrm.cxx b/sfx2/source/view/viewfrm.cxx
index a5e2cb63a457..8463b2366fbb 100644
--- a/sfx2/source/view/viewfrm.cxx
+++ b/sfx2/source/view/viewfrm.cxx
@@ -1219,7 +1219,7 @@ void SfxViewFrame::Notify( SfxBroadcaster& /*rBC*/, const SfxHint& rHint )
                 // inform about the community involvement
                 const sal_Int64 nLastShown = officecfg::Setup::Product::LastTimeGetInvolvedShown::get();
                 const sal_Int64 nNow = std::chrono::duration_cast<std::chrono::seconds>(std::chrono::system_clock::now().time_since_epoch()).count();
-                const sal_Int64 nPeriodSec(60 * 60 * 24 * 30); // 30 days in seconds
+                const sal_Int64 nPeriodSec(60 * 60 * 24 * 180); // 180 days in seconds
                 bool bUpdateLastTimeGetInvolvedShown = false;
 
                 if (nLastShown == 0)
@@ -1370,14 +1370,7 @@ void SfxViewFrame::Notify( SfxBroadcaster& /*rBC*/, const SfxHint& rHint )
 
 IMPL_LINK_NOARG(SfxViewFrame, GetInvolvedHandler, Button*, void)
 {
-    try
-    {
-        OUString sURL("https://hub.libreoffice.org/joinus/?LOlocale=" + utl::ConfigManager::getUILocale());
-        sfx2::openUriExternally(sURL, false);
-    }
-    catch (const Exception&)
-    {
-    }
+    GetDispatcher()->Execute(SID_GETINVOLVED);
 }
 
 IMPL_LINK(SfxViewFrame, SwitchReadOnlyHandler, Button*, pButton, void)


More information about the Libreoffice-commits mailing list